import { sha512_asm } from './sha512.asm.js';
import { Hash } from '../hash.js';
import { _heap_init } from '../../other/utils.js';
export const _sha512_block_size = 128;
export const _sha512_hash_size = 64;
const heap_pool = [];
const asm_pool = [];
export class Sha512 extends Hash {
    constructor() {
        super();
        this.NAME = 'sha512';
        this.BLOCK_SIZE = _sha512_block_size;
        this.HASH_SIZE = _sha512_hash_size;
        this.acquire_asm();
    }
    acquire_asm() {
        if (this.heap === undefined || this.asm === undefined) {
            this.heap = heap_pool.pop() || _heap_init();
            this.asm = asm_pool.pop() || sha512_asm({ Uint8Array: Uint8Array }, null, this.heap.buffer);
            this.reset();
        }
        return { heap: this.heap, asm: this.asm };
    }
    release_asm() {
        if (this.heap !== undefined && this.asm !== undefined) {
            heap_pool.push(this.heap);
            asm_pool.push(this.asm);
        }
        this.heap = undefined;
        this.asm = undefined;
    }
    static bytes(data) {
        return new Sha512().process(data).finish().result;
    }
}
Sha512.NAME = 'sha512';
